@@ -9,10 +9,9 @@ from dovado_rtl.frame_handling import (
     HdlBoxFrameHandler,
     XdcFrameHandler,
 )
-from dovado_rtl.enums import RTL, RegressionModel, StopStep
+from dovado_rtl.enums import RTL, StopStep
 from dovado_rtl.simple_types import IsIncremental
 from dovado_rtl.point_evaluation import DesignPointEvaluator
-from dovado_rtl.estimation import Estimator
 from dovado_rtl.fitness import FitnessEvaluator
 from dovado_rtl.genetic_algorithm import optimize
 from dovado_rtl.cli_utility import (
@@ -250,11 +249,6 @@ def space(
         + "'kernel_ridge' is default. 'stream_learning_isoup' selects a ISOUP Adaptive Tree Regressor trained incrementally "
         + "while 'stream_learning_stacked' selects a Stacked tree regressor",
     ),
-    nearest_distance: int = typer.Option(
-        3,
-        callback=validate_nearest_distance,
-        help="Set which nearest distance is considered against the threshold",
-    ),
     test_estimation: bool = typer.Option(
         False,
         help="record all estimated values along with the real "
@@ -276,20 +270,7 @@ def space(
     ranges_dict = OrderedDict(zip(ctx.obj["parameters"], zip(it, it)))
     estimator = None
     if approximate:
-        estimator = Estimator(
-            RegressionModel.STREAM_LEARNING_ISOUP
-            if fitness_estimator.upper() == "STREAM_LEARNING_ISOUP"
-            else RegressionModel.STREAM_LEARNING_STACKED
-            if fitness_estimator.upper() == "STREAM_LEARNING_STACKED"
-            else RegressionModel.KERNEL_RIDGE,
-            ctx.obj["point_evaluator"],
-            ranges_dict,
-            int(ctx.obj["config"].get_config("INITIAL_SAMPLES")),
-            ctx.obj["config"],
-            test_estimation,
-            record_design_values,
-            read_design_values,
-        )
+        raise Exception("To be implemented")
     else:
         if param_initial_values:
             design_value = ctx.obj["point_evaluator"].evaluate(
@@ -301,28 +282,10 @@ def space(
                     + str(param_initial_values)
                 )
         else:
+            raise Exception("To implement")
             # first estimation is to retrieve available utilization metrics
-            (
-                design_point,
-                design_value,
-            ) = Estimator.evaluate_random_design_point(
-                ranges_dict, ctx.obj["point_evaluator"]
-            )
-            i = 0
-            while (not design_value) and (i < 10):
-                print("Could not synthesize/implement " + str(design_point))
-                _, design_value = Estimator.evaluate_random_design_point(
-                    ranges_dict, ctx.obj["point_evaluator"]
-                )
-                i += 1
-            if i == 10:
-                raise Exception(
-                    "Could not find a valid design point in 10 attempts"
-                )
 
     fitness_evaluator = FitnessEvaluator(
-        nearest_distance,
-        estimator,
         ctx.obj["point_evaluator"],
         ctx.obj["config"],
     )
